pub struct KeyEventInjector;Expand description
The type corresponding to the KeyEventInjector protocol.
Provides the ability to inject KeyEvents into the keyboard subsystem.
Roles
This protocol will typically be:
- Implemented by platform components which process and deliver keyboard events.
- Consumed by components which originiate keyboard events. E.g. an on-screen keyboard, or the Session Framework Input Pipeline.
Related protocols
This protocol should be using in preference to legacy protocols which provide similar functionality. Specifically, this means this protocol should be preferred over
fuchsia.ui.input.ImeServicewhich providesInjectInput(),DispatchKey(), andDispatchKey3()fuchsia.ui.input.InputMethodEditor, which providesInjectInput()andDispatchKey3()
Notes
Products should take care to limit access to this protocol, as events injected with this protocol are indistinguishable from those coming from physical devices.