pub struct KeyEventInjectorInjectRequest {
pub key_event: KeyEvent,
}Fields
key_event: KeyEventTrait Implementations
Sourceimpl Clone for KeyEventInjectorInjectRequest
impl Clone for KeyEventInjectorInjectRequest
Sourcefn clone(&self) -> KeyEventInjectorInjectRequest
fn clone(&self) -> KeyEventInjectorInjectRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for KeyEventInjectorInjectRequest
Sourceimpl<___E> Encode<KeyEventInjectorInjectRequest<'static>, ___E> for KeyEventInjectorInjectRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<KeyEventInjectorInjectRequest<'static>, ___E> for KeyEventInjectorInjectRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<KeyEventInjectorInjectRequest<'static>, ___E> for &'a KeyEventInjectorInjectRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<KeyEventInjectorInjectRequest<'static>, ___E> for &'a KeyEventInjectorInjectRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, KeyEventInjectorInjectRequest<'static>>, ___E> for KeyEventInjectorInjectRequestwhere
___E: Encoder + ?Sized,
KeyEventInjectorInjectRequest: Encode<KeyEventInjectorInjectRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, KeyEventInjectorInjectRequest<'static>>, ___E> for KeyEventInjectorInjectRequestwhere
___E: Encoder + ?Sized,
KeyEventInjectorInjectRequest: Encode<KeyEventInjectorInjectRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<KeyEventInjectorInjectRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<KeyEventInjectorInjectRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, KeyEventInjectorInjectRequest<'static>>, ___E> for &'a KeyEventInjectorInjectRequestwhere
___E: Encoder + ?Sized,
&'a KeyEventInjectorInjectRequest: Encode<KeyEventInjectorInjectRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, KeyEventInjectorInjectRequest<'static>>, ___E> for &'a KeyEventInjectorInjectRequestwhere
___E: Encoder + ?Sized,
&'a KeyEventInjectorInjectRequest: Encode<KeyEventInjectorInjectRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a KeyEventInjectorInjectRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a KeyEventInjectorInjectRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, KeyEventInjectorInjectRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for KeyEventInjectorInjectRequest
Sourceimpl<'de> FromWire<KeyEventInjectorInjectRequest<'de>> for KeyEventInjectorInjectRequest
impl<'de> FromWire<KeyEventInjectorInjectRequest<'de>> for KeyEventInjectorInjectRequest
Sourcefn from_wire(
wire: KeyEventInjectorInjectRequest<'de>,
) -> KeyEventInjectorInjectRequest
fn from_wire( wire: KeyEventInjectorInjectRequest<'de>, ) -> KeyEventInjectorInjectRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<KeyEventInjectorInjectRequest<'de>> for KeyEventInjectorInjectRequest
impl<'de> FromWireRef<KeyEventInjectorInjectRequest<'de>> for KeyEventInjectorInjectRequest
Sourcefn from_wire_ref(
wire: &KeyEventInjectorInjectRequest<'de>,
) -> KeyEventInjectorInjectRequest
fn from_wire_ref( wire: &KeyEventInjectorInjectRequest<'de>, ) -> KeyEventInjectorInjectRequest
Converts the given reference to this type.
Sourceimpl Hash for KeyEventInjectorInjectRequest
impl Hash for KeyEventInjectorInjectRequest
Sourceimpl Ord for KeyEventInjectorInjectRequest
impl Ord for KeyEventInjectorInjectRequest
Sourcefn cmp(&self, other: &KeyEventInjectorInjectRequest) -> Ordering
fn cmp(&self, other: &KeyEventInjectorInjectRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for KeyEventInjectorInjectRequest
impl PartialOrd for KeyEventInjectorInjectRequest
impl StructuralPartialEq for KeyEventInjectorInjectRequest