pub enum KeyMeaning {
Codepoint(u32),
NonPrintableKey(NonPrintableKey),
}Expand description
The meaning of the key press. This is typically the Unicode codepoint inserted by this event, or an enum representing a key that corresponds to whitespace or is otherwise unprintable.
Variants
Codepoint(u32)
NonPrintableKey(NonPrintableKey)