NonPrintableKey

Enum NonPrintableKey 

#[repr(u32)]
pub enum NonPrintableKey {
Show 59 variants Unidentified = 0, Alt = 17, AltGraph = 18, CapsLock = 19, Control = 20, Fn = 21, FnLock = 22, Meta = 23, NumLock = 24, ScrollLock = 25, Shift = 26, Symbol = 27, SymbolLock = 28, Hyper = 29, Super = 30, Enter = 49, Tab = 50, Backspace = 65, Down = 97, Left = 98, Right = 99, Up = 100, End = 101, Home = 102, PageDown = 103, PageUp = 104, Escape = 24_581, Select = 24_588, BrightnessDown = 28_672, BrightnessUp = 28_673, F1 = 36_865, F2 = 36_866, F3 = 36_867, F4 = 36_868, F5 = 36_869, F6 = 36_870, F7 = 36_871, F8 = 36_872, F9 = 36_873, F10 = 36_874, F11 = 36_875, F12 = 36_876, Soft1 = 36_881, Soft2 = 36_882, Soft3 = 36_883, Soft4 = 36_884, MediaPlayPause = 40_968, AudioVolumeDown = 49_162, AudioVolumeUp = 49_163, AudioVolumeMute = 49_164, BrowserBack = 61_440, BrowserFavorites = 61_441, BrowserForward = 61_442, BrowserHome = 61_443, BrowserRefresh = 61_444, BrowserSearch = 61_445, BrowserStop = 61_446, ZoomToggle = 73_799, UnknownOrdinal_(u32),
}
NonPrintableKey represents the meaning of a non-symbolic key on a keyboard.

The definition of each key is derived from W3C named values of a key attribute.

API version 9 and onwards

Starting from API version 9, the enum value space is subdivided based on the subsection numbers of the section Named Key Attribute Values, multiplied by 0x1000.

For example, the keys from section 3.10 Multimedia keys will be located at 0xa000-0xafff. The values and reservations that were present in this enum prior to the introduction of the convention have not been moved, and values that go logically into pre-existing sections have been inserted into their logical place using the prior convention (see below). This allows us to extract the section ranges if this is for some reason useful to the application.

Prior to API version 9

The space of the nonprintable keys is subdivided roughly to correspond to the subsections of Section 3 of the document Named Key Attribute Values. The choice for the section values is arbitrary, so long as blocks of values are allocated at once, and the keys with similar purpose are kept together.

Reserved ranges

The space of possible values for NonPrintableKey is subdivided into a number of ranges, with the intention that the enum values are placed in the appropriate range when added.

  • Special keys: 0x00-0x10
  • Modifier keys: 0x11-0x30
  • Whitespace keys: 0x31-0x40
  • Navigation keys: 0x61-0x80
  • General-purpose function keys: 0x9000-0x9FFF

Variants



Unidentified = 0



Alt = 17



AltGraph = 18



CapsLock = 19



Control = 20



Fn = 21



FnLock = 22



Meta = 23



NumLock = 24



ScrollLock = 25



Shift = 26



Symbol = 27



SymbolLock = 28



Hyper = 29



Super = 30



Enter = 49



Tab = 50



Backspace = 65



Down = 97



Left = 98



Right = 99



Up = 100



End = 101



Home = 102



PageDown = 103



PageUp = 104



Escape = 24_581



Select = 24_588



BrightnessDown = 28_672



BrightnessUp = 28_673



F1 = 36_865



F2 = 36_866



F3 = 36_867



F4 = 36_868



F5 = 36_869



F6 = 36_870



F7 = 36_871



F8 = 36_872



F9 = 36_873



F10 = 36_874



F11 = 36_875



F12 = 36_876



Soft1 = 36_881



Soft2 = 36_882



Soft3 = 36_883



Soft4 = 36_884



MediaPlayPause = 40_968



AudioVolumeDown = 49_162



AudioVolumeUp = 49_163



AudioVolumeMute = 49_164



BrowserBack = 61_440



BrowserFavorites = 61_441



BrowserForward = 61_442



BrowserHome = 61_443



BrowserRefresh = 61_444



BrowserSearch = 61_445



BrowserStop = 61_446



ZoomToggle = 73_799



UnknownOrdinal_(u32)