#[repr(C)]pub struct KeyEventInjectorInjectResponse {
pub status: KeyEventStatus,
}Expand description
The wire type corresponding to KeyEventInjectorInjectResponse.
Fields
status: KeyEventStatusTrait Implementations
Sourceimpl Clone for KeyEventInjectorInjectResponse
impl Clone for KeyEventInjectorInjectResponse
Sourcefn clone(&self) -> KeyEventInjectorInjectResponse
fn clone(&self) -> KeyEventInjectorInjectResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for KeyEventInjectorInjectResponse
impl Constrained for KeyEventInjectorInjectResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, KeyEventInjectorInjectResponse>,
_: <KeyEventInjectorInjectResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, KeyEventInjectorInjectResponse>, _: <KeyEventInjectorInjectResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for KeyEventInjectorInjectResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for KeyEventInjectorInjectResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<KeyEventInjectorInjectResponse, ___E> for KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<KeyEventInjectorInjectResponse, ___E> for KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<KeyEventInjectorInjectResponse, KeyEventInjectorInjectResponse>
const COPY_OPTIMIZATION: CopyOptimization<KeyEventInjectorInjectResponse, KeyEventInjectorInjectResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<KeyEventInjectorInjectResponse, ___E> for &'a KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<KeyEventInjectorInjectResponse, ___E> for &'a KeyEventInjectorInjectResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<KeyEventInjectorInjectResponse, ___E> for KeyEventInjectorInjectResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<KeyEventStatus, ___E>,
impl<___E, T0> Encode<KeyEventInjectorInjectResponse, ___E> for KeyEventInjectorInjectResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<KeyEventStatus, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
impl FromWire<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<KeyEventInjectorInjectResponse, KeyEventInjectorInjectResponse>
const COPY_OPTIMIZATION: CopyOptimization<KeyEventInjectorInjectResponse, KeyEventInjectorInjectResponse>
Sourcefn from_wire(
wire: KeyEventInjectorInjectResponse,
) -> KeyEventInjectorInjectResponse
fn from_wire( wire: KeyEventInjectorInjectResponse, ) -> KeyEventInjectorInjectResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
impl FromWireRef<KeyEventInjectorInjectResponse> for KeyEventInjectorInjectResponse
Sourcefn from_wire_ref(
wire: &KeyEventInjectorInjectResponse,
) -> KeyEventInjectorInjectResponse
fn from_wire_ref( wire: &KeyEventInjectorInjectResponse, ) -> KeyEventInjectorInjectResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for KeyEventInjectorInjectResponse
impl IntoNatural for KeyEventInjectorInjectResponse
Sourcetype Natural = KeyEventInjectorInjectResponse
type Natural = KeyEventInjectorInjectResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for KeyEventInjectorInjectResponse
impl Wire for KeyEventInjectorInjectResponse
Sourcetype Narrowed<'de> = KeyEventInjectorInjectResponse
type Narrowed<'de> = KeyEventInjectorInjectResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>)
fn zero_padding(out_: &mut MaybeUninit<KeyEventInjectorInjectResponse>)
Writes zeroes to the padding for this type, if any.